@@ -25,8 +25,8 @@ import shutil
 import xdg.DesktopEntry
 import xdg.Menu
 
-from execute import *
-from filemonitor import monitor as filemonitor
+from .execute import *
+from .filemonitor import monitor as filemonitor
 from gi.repository import Gtk, Gdk, GLib, GdkPixbuf
 from gi.repository.GdkPixbuf import Pixbuf
 from gi.repository import Pango
@@ -65,10 +65,10 @@ class IconManager(GObject.GObject):
         contents = frozenset(os.listdir(self.iconDir)) - frozenset(('applications', 'applications.list'))
         for fn in contents:
             if os.path.isfile(os.path.join(self.iconDir, fn)):
-                print "Removing file : " + os.path.join(self.iconDir, fn)
+                print (("Removing file : " + os.path.join(self.iconDir, fn)))
                 os.remove(os.path.join(self.iconDir, fn))
             else:
-                print os.path.join(self.iconDir, fn) + " is not a file, skipping delete."
+                print ((os.path.join(self.iconDir, fn) + " is not a file, skipping delete."))
 
         self.defaultTheme.append_search_path(self.iconDir)
 
@@ -127,8 +127,8 @@ class IconManager(GObject.GObject):
                 image.set_pixel_size(iconSize)
 
             return image
-        except Exception, e:
-            print "Exception " + e.__class__.__name__ + ": " + e.message
+        except Exception as e:
+            print (("Exception " + e.__class__.__name__ + ": " + e.message))
             return None
 
     def themeChanged( self, theme ):
@@ -168,7 +168,7 @@ class easyButton( Gtk.Button ):
 
         if labels:
             for label in labels:
-                if isinstance( label, basestring ):
+                if isinstance( label, str ):
                     self.addLabel( label )                   
                 elif isinstance( label, list ):
                     self.addLabel( label[0], label[1] )
@@ -321,10 +321,10 @@ class ApplicationLauncher( easyButton ):
 
     def loadDesktopEntry( self, desktopItem ):
         try:
-            self.appName = self.strip_accents(desktopItem.getName())
-            self.appGenericName = self.strip_accents(desktopItem.getGenericName())
-            self.appComment = self.strip_accents(desktopItem.getComment())
-            self.appExec = self.strip_accents(desktopItem.getExec())
+            self.appName = desktopItem.getName()
+            self.appGenericName = desktopItem.getGenericName()
+            self.appComment = desktopItem.getComment()
+            self.appExec = desktopItem.getExec()
             self.appIconName = desktopItem.getIcon()
             self.appCategories = desktopItem.getCategories()
             self.appUkuiDocPath = desktopItem.get( "X-MATE-DocPath" ) or ""
@@ -351,8 +351,8 @@ class ApplicationLauncher( easyButton ):
             if os.path.exists (self.startupFilePath):
                 self.startupMonitorId = filemonitor.addMonitor( self.startupFilePath, self.startupFileChanged )
 
-        except Exception, e:
-            print e
+        except Exception as e:
+            print (e)
             self.appName            = ""
             self.appGenericName     = ""
             self.appComment         = ""
@@ -373,6 +373,8 @@ class ApplicationLauncher( easyButton ):
         self.addLabel( self.appName )
 
     def filterText( self, text, var ):
+        if text == "":
+            return
         keywords = text.lower().split()
         appName = self.appName.lower()
         appGenericName = self.appGenericName.lower()
@@ -380,36 +382,24 @@ class ApplicationLauncher( easyButton ):
         appExec = self.appExec.lower()
 
         if var == 1:
-            for keyword in keywords:
-                keyw = self.strip_accents(keyword)
+            for keyw in keywords:
                 if keyw != "" and appName.startswith( keyw ):
                     return True
                 else:
                     return False
         if var == 2:
-            for keyword in keywords:
-                keyw = self.strip_accents(keyword)
+            for keyw in keywords:
                 if keyw != "" and appName.find( keyw ) == -1:
                     return False
                 else:
                     return True
         if var == 3:
-            for keyword in keywords:
-                keyw = self.strip_accents(keyword)
+            for keyw in keywords:
                 if keyw != "" and appGenericName.find( keyw ) == -1 and appComment.find( keyw ) == -1 and appExec.find( keyw ) == -1:
                     return False
                 else:
                     return True
 
-    def strip_accents(self, string):
-        value = string
-        if isinstance(string, unicode):
-            try:
-                value = string.encode('UTF8', 'ignore')
-            except:
-                pass
-        return value
-
     def getTooltip( self ):
         tooltip = self.appName
         if self.appComment != "" and self.appComment != self.appName:
@@ -462,21 +452,6 @@ class ApplicationLauncher( easyButton ):
     def startupFileChanged( self, *args ):
         self.inStartup = os.path.exists( self.startupFilePath )
 
-    def addToStartup( self ):
-        startupDir = os.path.join( os.path.expanduser("~"), ".config", "autostart" )
-        if not os.path.exists( startupDir ):
-            os.makedirs( startupDir )
-
-        shutil.copyfile( self.desktopFile, self.startupFilePath )
-  
-        # Remove %u, etc. from Exec entry, because MATE will not replace them when it starts the app
-        item = matedesktop.item_new_from_uri( self.startupFilePath, matedesktop.LOAD_ONLY_IF_EXISTS )
-        if item:
-            r = re.compile("%[A-Za-z]");
-            tmp = r.sub("", item.get_string( matedesktop.KEY_EXEC ) ).strip()
-            item.set_string( matedesktop.KEY_EXEC, tmp )
-            item.save( self.startupFilePath, 0 )
-
     def removeFromStartup( self ):
         if os.path.exists( self.startupFilePath ):
             os.remove( self.startupFilePath )
@@ -564,8 +539,8 @@ class MenuApplicationLauncher( ApplicationLauncher ):
                     #appComment = "<b>%s</b>" % (appComment);
                 appName = "<b>%s</b>" % (appName);
                 appComment = "<b>%s</b>" % (appComment);
-            except Exception, detail:
-                print detail
+            except Exception as detail:
+                print (detail)
                 pass
         
         if self.showComment and self.appComment != "":
